==> moodle-1.5-pgsql.tgz: moodle/lang/sk/block_glossary_random.php <==
<?PHP // $Id$ 
      // block_glossary_random.php - created with Moodle 1.6 development (2005053000)


$string['addentry'] = 'Pridajte V obben citt!';
$string['askaddentry'] = 'Ak mu uvatelia pridva zznamy do slovnku, zobraz odkaz s tmto textom';
$string['askinvisible'] = 'Ak nemu uvatelia pridva zznamy do slovnku, zobraz tento text (bez odkazu)';
$string['askviewglossary'] = 'Ak si uvatelia mu prezera slovnk, ale nemu doho vklada poloky, zobraz odkaz s tmto textom';
$string['blockname'] = 'Nhodn poloka slovnku';
$string['intro'] = 'Uistite sa, e mte vo svojom kurze aspo jeden slovnk s aspo jednm zznamom. Potom mete upravi nasledujce nastavenia';
$string['invisible'] = '(pokraovanie)';
$string['lastmodified'] = 'Naposledy upravovan poloka slovnku';
$string['nextone'] = 'alia poloka';
$string['noentriesyet'] = 'Zvolen slovnk zatia neobsahuje iadne poloky.';
$string['notyetconfigured'] = 'Prosm, upravte nastavenia tohto bloku pomocou ikonky prav.';
$string['notyetglossary'] = 'Muste ma k dispozcii aspo jeden slovnk.';
$string['random'] = 'Nhodn poloka';
$string['refresh'] = 'Poet dn predtm, ako bude vybran nov poloka';
$string['select_glossary'] = 'Vybra poloky z tohto slovnka';
$string['showconcept'] = 'Zobrazi nzov (hlaviku) pre kad poloku';
$string['title'] = 'Nadpis';
$string['type'] = 'Ako m by vybran nov poloka ';
$string['typehelp'] = '<b>Naposledy upravovan poloka</b> vdy zobrazuje posledn upravovan poloku, zatia o <b>Nhodn poloka</b> ju zakadm nhodne vyber. Voba <b>alia poloka</b> prechdza slovnkom poda poradia poloiek. Tto posledn voba je vemi uiton, pokia zrove nastavte poet dn. Tak si mete vytvori blok obsahujci napr. <i>Citt tda</i> i <i>Tip pre dnen de</i>.';
$string['viewglossary'] = 'Viac cittov...';
$string['whichfooter'] = 'Mete necha zobrazova odkazy na akcie slovnka, s ktormi je tento blok asociovan. Blok bude zobrazova iba tie akcie, ktor s v danom slovnku povolen.';

?>

==> moodle-1.5.3-pgsql.tgz: moodle/lang/sk/block_glossary_random.php <==
<?PHP // $Id$ 
      // block_glossary_random.php - created with Moodle 1.6 development (2005053000)


$string['addentry'] = 'Pridajte V obben citt!';
$string['askaddentry'] = 'Ak mu pouvatelia pridva zznamy do slovnku, zobraz odkaz s tmto textom';
$string['askinvisible'] = 'Ak nemu pouvatelia pridva zznamy do slovnku, zobraz tento text (bez odkazu)';
$string['askviewglossary'] = 'Ak si pouvatelia mu prezera slovnk, ale nemu doho vklada poloky, zobraz odkaz s tmto textom';
$string['blockname'] = 'Nhodn poloka slovnku';
$string['intro'] = 'Uistite sa, e mte vo svojom kurze aspo jeden slovnk s aspo jednm zznamom. Potom mete upravi nasledujce nastavenia';
$string['invisible'] = '(pokraovanie)';
$string['lastmodified'] = 'Naposledy upravovan poloka slovnku';
$string['nextone'] = 'alia poloka';
$string['noentriesyet'] = 'Zvolen slovnk zatia neobsahuje iadne poloky.';
$string['notyetconfigured'] = 'Prosm, upravte nastavenia tohto bloku pomocou ikonky prav.';
$string['notyetglossary'] = 'Muste ma k dispozcii aspo jeden slovnk.';
$string['random'] = 'Nhodn poloka';
$string['refresh'] = 'Poet dn predtm, ako bude vybran nov poloka';
$string['select_glossary'] = 'Vybra poloky z tohto slovnka';
$string['showconcept'] = 'Zobrazi nzov (hlaviku) pre kad poloku';
$string['title'] = 'Nadpis';
$string['type'] = 'Ako m by vybran nov poloka ';
$string['typehelp'] = '<b>Naposledy upravovan poloka</b> vdy zobrazuje posledn upravovan poloku, zatia o <b>Nhodn poloka</b> ju zakadm nhodne vyber. Voba <b>alia poloka</b> prechdza slovnkom poda poradia poloiek. Tto posledn voba je vemi uiton, pokia zrove nastavte poet dn. Tak si mete vytvori blok obsahujci napr. <i>Citt tda</i> i <i>Tip pre dnen de</i>.';
$string['viewglossary'] = 'Viac cittov...';
$string['whichfooter'] = 'Mete necha zobrazova odkazy na akcie slovnka, s ktormi je tento blok asociovan. Blok bude zobrazova iba tie akcie, ktor s v danom slovnku povolen.';

?>
